// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KSERVICE_VERSION_H
#define KSERVICE_VERSION_H

#define KSERVICE_VERSION_STRING "6.23.1"
#define KSERVICE_VERSION_MAJOR 6
#define KSERVICE_VERSION_MINOR 23
#define KSERVICE_VERSION_PATCH 1
#define KSERVICE_VERSION ((6<<16)|(23<<8)|(1))

#endif
